weaviate.collections.grpc package
=================================

.. automodule:: weaviate.collections.grpc
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

weaviate.collections.grpc.query module
--------------------------------------

.. automodule:: weaviate.collections.grpc.query
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.grpc.shared module
---------------------------------------

.. automodule:: weaviate.collections.grpc.shared
   :members:
   :undoc-members:
   :show-inheritance:
